{% extends "base.html" %}

{% block title %}Extract{% endblock %}

{% block extra_head %}
<link type="text/css" rel="stylesheet" href="/-/static-plugins/datasette-extract/extract.css">
{% endblock %}

{% block content %}
<h1>Extract</h1>
{% endblock %}
